==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QIconEngine_shell.h <==
#ifndef QICONENGINE_SHELL_H
#define QICONENGINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qiconengine.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qdatastream.h>
#include <QtCore/qrect.h>
#include <QtCore/qsize.h>
#include <QtGui/qicon.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpixmap.h>
#include <QtJambi/RegistryAPI>


class QIconEngine_shell : public QIconEngine, public QtJambiShellInterface
{
public:
    QIconEngine_shell();
    QIconEngine_shell(const QIconEngine& other0);
    ~QIconEngine_shell() override;

    QSize actualSize(const QSize& size0, QIcon::Mode mode1, QIcon::State state2) override;
    void addFile(const QString& fileName0, const QSize& size1, QIcon::Mode mode2, QIcon::State state3) override;
    void addPixmap(const QPixmap& pixmap0, QIcon::Mode mode1, QIcon::State state2) override;
    QList<QSize> availableSizes(QIcon::Mode mode0, QIcon::State state1) override;
    QIconEngine* clone() const override;
    QString iconName() override;
    bool isNull() override;
    QString key() const override;
    void paint(QPainter* painter0, const QRect& rect1, QIcon::Mode mode2, QIcon::State state3) override;
    QPixmap pixmap(const QSize& size0, QIcon::Mode mode1, QIcon::State state2) override;
    bool read(QDataStream& in0) override;
    QPixmap scaledPixmap(const QSize& size0, QIcon::Mode mode1, QIcon::State state2, qreal scale3) override;
    bool write(QDataStream& out0) const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QIconEngine_access : public QIconEngine
{
    jobject __qt_actualSize_cref_QSize_QIcon_Mode_QIcon_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID size0, jint mode1, jint state2);
    void __qt_addFile_cref_QString_cref_QSize_QIcon_Mode_QIcon_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring fileName0, QtJambiNativeID size1, jint mode2, jint state3);
    void __qt_addPixmap_cref_QPixmap_QIcon_Mode_QIcon_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID pixmap0, jint mode1, jint state2);
    jobject __qt_availableSizes_QIcon_Mode_QIcon_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0, jint state1);
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_iconName(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_isNull(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jstring __qt_key(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_paint_QPainter_ptr_cref_QRect_QIcon_Mode_QIcon_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID rect1, jint mode2, jint state3);
    jobject __qt_pixmap_cref_QSize_QIcon_Mode_QIcon_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID size0, jint mode1, jint state2);
    jboolean __qt_read_ref_QDataStream(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID in0);
    jobject __qt_scaledPixmap_cref_QSize_QIcon_Mode_QIcon_State_qreal(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID size0, jint mode1, jint state2, jdouble scale3);
    jboolean __qt_write_ref_QDataStream_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID out0) const;
};

#endif // QICONENGINE_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QIconEngine_shell.h <==
#ifndef QICONENGINE_SHELL_H
#define QICONENGINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qiconengine.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qdatastream.h>
#include <QtCore/qrect.h>
#include <QtCore/qsize.h>
#include <QtGui/qicon.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpixmap.h>
#include <QtJambi/RegistryAPI>


class QIconEngine_shell : public QIconEngine, public QtJambiShellInterface
{
public:
    QIconEngine_shell();
    QIconEngine_shell(const QIconEngine& other0);
    ~QIconEngine_shell() override;

    QSize actualSize(const QSize& size0, QIcon::Mode mode1, QIcon::State state2) override;
    void addFile(const QString& fileName0, const QSize& size1, QIcon::Mode mode2, QIcon::State state3) override;
    void addPixmap(const QPixmap& pixmap0, QIcon::Mode mode1, QIcon::State state2) override;
    QList<QSize> availableSizes(QIcon::Mode mode0, QIcon::State state1) override;
    QIconEngine* clone() const override;
    QString iconName() override;
    bool isNull() override;
    QString key() const override;
    void paint(QPainter* painter0, const QRect& rect1, QIcon::Mode mode2, QIcon::State state3) override;
    QPixmap pixmap(const QSize& size0, QIcon::Mode mode1, QIcon::State state2) override;
    bool read(QDataStream& in0) override;
    QPixmap scaledPixmap(const QSize& size0, QIcon::Mode mode1, QIcon::State state2, qreal scale3) override;
    void virtual_hook(int id0, void* data1) override;
    bool write(QDataStream& out0) const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QIconEngine_access : public QIconEngine
{
    jobject __qt_actualSize_cref_QSize_QIcon_Mode_QIcon_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID size0, jint mode1, jint state2);
    void __qt_addFile_cref_QString_cref_QSize_QIcon_Mode_QIcon_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring fileName0, QtJambiNativeID size1, jint mode2, jint state3);
    void __qt_addPixmap_cref_QPixmap_QIcon_Mode_QIcon_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID pixmap0, jint mode1, jint state2);
    jobject __qt_availableSizes_QIcon_Mode_QIcon_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0, jint state1);
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_iconName(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_isNull(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jstring __qt_key_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_paint_QPainter_ptr_cref_QRect_QIcon_Mode_QIcon_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID rect1, jint mode2, jint state3);
    jobject __qt_pixmap_cref_QSize_QIcon_Mode_QIcon_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID size0, jint mode1, jint state2);
    jboolean __qt_read_ref_QDataStream(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID in0);
    jobject __qt_scaledPixmap_cref_QSize_QIcon_Mode_QIcon_State_qreal(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID size0, jint mode1, jint state2, jdouble scale3);
    void __qt_virtual_hook_int_void_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject id0, jobject data1);
    jboolean __qt_write_ref_QDataStream_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID out0) const;
};

#endif // QICONENGINE_SHELL_H
